# nafes


[![image](https://img.shields.io/pypi/v/nafes.svg)](https://pypi.python.org/pypi/nafes)
[![image](https://img.shields.io/conda/vn/conda-forge/nafes.svg)](https://anaconda.org/conda-forge/nafes)
[![python: 3.10](https://img.shields.io/badge/python-3.10-blue.svg)](https://www.python.org/downloads/release/python-31011/)
[![github](https://img.shields.io/badge/version-0.0.2-yellow.svg)](https://github.com/naotoo1/nafes)
[![pypi](https://img.shields.io/badge/pypi-0.0.1-orange.svg)](https://pypi.org/project/nafes)
[![License: MIT](https://img.shields.io/badge/License-MIT-green.svg)](https://opensource.org/licenses/MIT)


**A python package for prototype-based feature selection**

Nafes is a prototype-based feature selection package designed as a wrapper centered on the highly interpretable and powerful Generalized Matrix Learning Vector Quantization (GMLVQ) classification algorithm and its local variant (LGMLVQ). Nafes utilizes the learned relevances evaluated by the mutation validation scheme for Learning Vector quantization (LVQ), which iteratively converges to selected features that relevantly contribute to the prototype-based classifier decisions. 

    

## Installation
nafes can be installed using pip.
```python
pip install nafes
```





## Bibtex
If you would like to cite the package, please use this:
```python
@misc{Otoo_nafes_2023,
author = {Otoo, Nana Abeka},
title = {nafes},
year = {2023},
publisher = {GitHub},
journal = {GitHub repository},
howpublished= {\url{https://github.com/naotoo1/nafes}},
}
```

